@@ -141,13 +141,13 @@ class CraftingWorldEnv(gym.GoalEnv):
 
         # reset gif
         if self.store_gif:
-            plt.close()
-            self.fig, self.ax = plt.subplots(1)
+            if self.fig is None:
+                self.fig, self.ax = plt.subplots(1)
+            else:
+                plt.clf()
             self.ims = []
             self.__render_gif()
 
-
-
     def step(self, action):
         """
         take a step within the environment
